//
//  NFCReadViewController.m
//  AsReader 6Combo
//
//  Created by mac on 2019/2/13.
//

#import "NFCReadViewController.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

@interface NFCReadViewController ()<AsReaderNFCDeviceDelegate>

@property (weak, nonatomic) IBOutlet UITextField *blockIndexTextField;
@property (weak, nonatomic) IBOutlet UITextField *blockCountTextField;
@property (weak, nonatomic) IBOutlet UIButton *readButton;
@property (weak, nonatomic) IBOutlet UITextView *readTextView;
@end

@implementation NFCReadViewController

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.readButton.layer.masksToBounds = YES;
    self.readButton.layer.cornerRadius = 5;
    self.readTextView.layer.masksToBounds = YES;
    self.readTextView.layer.cornerRadius = 5;
    self.readTextView.layer.borderColor = [[UIColor lightGrayColor] CGColor];
    self.readTextView.layer.borderWidth = 0.5;
    
    ModelSettings *model = [ModelSettings sharedInstance];
    NSDictionary *dic = [model.m_arReadTagData objectAtIndex:model.m_nSelectTagNum];
    NSString *strData = [dic objectForKey:df_CELL_TAG_INFO];
    [self setTextBlockAttributed:[NSString stringWithFormat:@"UID : %@",strData]];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [AsReaderNFCDevice sharedInstance].delegateNFC = self;
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderNFCDevice sharedInstance].delegateNFC = nil;
}

#pragma mark - UIEvent
//----------------------------------------------------------------
- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event
{
    [self.view endEditing:YES];
}

#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)readAction:(id)sender
{
    [self.view endEditing:YES];
    if (![Utils checkNumberTextLength:self.blockIndexTextField.text maxNumber:255 minNumber:0]) {
        [self setTextBlockAttributed:@"The value of the block index is in the range 0-255. Please enter a valid value"];
        return;
    } else if (![Utils checkNumberTextLength:self.blockCountTextField.text maxNumber:255 minNumber:0]) {
        [self setTextBlockAttributed:@"The value of the block count is in the range 0-255. Please enter a valid value"];
        return;
    } else {
        [[AsReaderNFCDevice sharedInstance] readMultiBlockWithBlockIndex:[self.blockIndexTextField.text intValue] count:[self.blockCountTextField.text intValue]];
    }
}

#pragma mark - Private method
//----------------------------------------------------------------
- (void)setTextBlockAttributed:(NSString *)text
{
    NSMutableAttributedString *string = [[NSMutableAttributedString alloc]initWithString:text];
    [string addAttribute:NSFontAttributeName value:[UIFont systemFontOfSize:20] range:NSMakeRange(0, text.length)];
    NSArray * array = [text componentsSeparatedByString:@"\n"];
    for (NSString * str in array) {
        if ([str hasPrefix:@"Block"]) {
            [string addAttribute:NSForegroundColorAttributeName value:[UIColor blueColor] range:[text rangeOfString:str]];
        } else {
            [string addAttribute:NSForegroundColorAttributeName value:[UIColor blackColor] range:[text rangeOfString:str]];
        }
    }
    [self.readTextView setAttributedText:string];
}

#pragma mark - AsReaderNFCDeviceDelegate
//----------------------------------------------------------------
- (void)nfcDataReceived:(NSData *)data
{
    NSLog(@"nfcDataReceived APP: %@",data);
}

- (void)nfcReadMultiBlockReceived:(NSArray *)dataArray statusCode:(SDK4StatusCode)statusCode
{
    if (statusCode == SDK4_STS_OK) {
        NSInteger blockIndex = [self.blockIndexTextField.text integerValue];
        NSMutableString *allBlockString = [[NSMutableString alloc] init];
        for (int i = 0; i < dataArray.count; i++){
            NSString * blockString = [NSString stringWithFormat:@"Block %ld:\n%@\n", (long)blockIndex, [dataArray objectAtIndex:i]];
            [allBlockString appendString:blockString];
            blockIndex ++;
        }
        [self setTextBlockAttributed:allBlockString];
        [Utils showAlert:@"Read Success" message:@"" view:self];
    } else {
        [Utils showAlert:@"Read Failed" message:[NSString stringWithFormat:@"StatusCode：0x%02lx", (unsigned long)statusCode] view:self];
    }
}

@end
