//  SessionController.m

#import "SessionController.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

@interface SessionController ()<AsReaderRFIDDeviceDelegate>
@property (nonatomic, assign)NSInteger session;
@end

@implementation SessionController

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.session = -1;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateRFID = self;
    [[AsReaderRFIDDevice sharedInstance] getSession];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateRFID = nil;
}

#pragma mark - Private method
//----------------------------------------------------------------
- (void)didSetSession:(int)status
{
    if( status==0) {
        dispatch_async(dispatch_get_main_queue(),^{
            [Utils showAlert:@"" message:@"Changed Session" view:self];
       });
    }
}

#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)rightBarButtonItemClicked:(id)sender
{
    if(self.session == -1) {
        [[AsReaderRFIDDevice sharedInstance]  setSession:0];
        self.session = 0;
    } else {
        [[AsReaderRFIDDevice sharedInstance] setSession:(int)self.session];
    }
    NSString *strMessage = [NSString stringWithFormat:@"%@ : %d", @"Set Session",(int)self.session ];
    
    dispatch_async(dispatch_get_main_queue(), ^{
        [Utils showAlert:@"1) Update Registry \n2) Reset Hardware" message:strMessage view:self];
    });
}

#pragma mark - UITableView Data source
//----------------------------------------------------------------
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    //#warning Potentially incomplete method implementation.
    // Return the number of sections.
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return 4;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    cell.textLabel.text = [NSString stringWithFormat:@"S%d", (int)indexPath.row];
    
    if(self.session == indexPath.row) {
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    } else {
        cell.accessoryType = UITableViewCellAccessoryNone;
    }
    return cell;
}

#pragma mark - UITableView Delegate
//----------------------------------------------------------------
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    self.session = (int)indexPath.row;
    [self.tableView reloadData];
}


#pragma mark - AsReaderRFIDDeviceDelegate
//----------------------------------------------------------------
- (void)sessionReceived:(int)session
{
    self.session = session;
    dispatch_async(dispatch_get_main_queue(), ^{
       [self.tableView reloadData];
   });
}

@end
